@@ -1966,6 +1966,45 @@ class TestCreateCluster(BaseAWSCommandParamsTest):
         }
         self.assert_params_for_cmd(cmd, result)
 
+    def test_create_cluster_with_steps_with_step_monitoring_configuration(
+        self,
+    ):
+        # For ease of testing, we only test the handling of StepMonitoringConfig in create-cluster
+        # with a CUSTOM_JAR step. Under the hood, it uses the same handler as add-steps. The remaining
+        # step types are unit tested in test_add_steps.py.
+        cmd = (
+            DEFAULT_CMD
+            + '--steps '
+            + (
+                'Name=Custom,Type=Custom_JAR,'
+                'Jar=s3://mybucket/mytest.jar,'
+                'Args=arg1,arg2,MainClass=mymainclass,'
+                'ActionOnFailure=TERMINATE_CLUSTER,'
+                'LogUri=TestLogUri,'
+                'EncryptionKeyArn=TestEncryptionKeyArn'
+            )
+        )
+        expected_steps = [
+            {
+                'Name': 'Custom',
+                'ActionOnFailure': 'TERMINATE_CLUSTER',
+                'HadoopJarStep': {
+                    'Jar': 's3://mybucket/mytest.jar',
+                    'Args': ['arg1', 'arg2'],
+                    'MainClass': 'mymainclass',
+                },
+                'StepMonitoringConfiguration': {
+                    'S3MonitoringConfiguration': {
+                        'LogUri': 'TestLogUri',
+                        'EncryptionKeyArn': 'TestEncryptionKeyArn',
+                    }
+                },
+            }
+        ]
+        result = copy.deepcopy(DEFAULT_RESULT)
+        result['Steps'] = expected_steps
+        self.assert_params_for_cmd(cmd, result)
+
 
 if __name__ == "__main__":
     unittest.main()
